package com.yhx.union;

import android.content.Intent;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;

import androidx.lifecycle.Lifecycle;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.uber.autodispose.AutoDispose;
import com.uber.autodispose.android.lifecycle.AndroidLifecycleScopeProvider;
import com.yhx.union.activity.NewListActivity;
import com.yhx.union.adapter.NewAdapter;
import com.yhx.union.entity.BannerEntity;
import com.yhx.union.entity.BaseResponse;
import com.yhx.union.entity.NewBean;
import com.yhx.union.entity.request.NewListRequest;
import com.yhx.union.public_store.ConstDefine;
import com.yhx.union.public_store.retrofit.RetrofitUtils;
import com.yhx.union.public_store.retrofit.UnionServices;
import com.yhx.union.public_store.rx.DefaultSubscriber;
import com.yhx.union.system.BaseFragment;
import com.yhx.union.system.WebviewActivity;

import java.util.ArrayList;
import java.util.List;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import cn.bingoogolapple.bgabanner.BGABanner;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.annotations.Nullable;
import io.reactivex.schedulers.Schedulers;

/**
 * 描述:
 *
 * @author yanghuaxiong
 * @create 2021/9/1 11:44 AM
 */

public class HomeFragment extends BaseFragment {
    @BindView(R.id.bga_banner)
    BGABanner bgaBanner;
    @BindView(R.id.recyclerView)
    RecyclerView recyclerView;

    private List<BannerEntity> bannerEntities = new ArrayList<>();
    private List<NewBean> beans = new ArrayList<>();
    private NewAdapter adapter;
    private UnionServices services;

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Nullable
    @Override
    public View onCreateView(final LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        setHasOptionsMenu(true);
        View view = inflater.inflate(R.layout.fragment_home, container, false);
        ButterKnife.bind(this, view);
        init();
        return view;
    }

    private void init(){
        services = RetrofitUtils.createApi(UnionServices.class, ConstDefine.HttpAdress);
        bgaBanner.setAdapter(new BGABanner.Adapter<ImageView, String>() {
            @Override
            public void fillBannerItem(BGABanner banner, ImageView itemView, String model, int position) {
                Glide.with(getActivity())
                        .load(model)
                        .placeholder(R.mipmap.bg_placeholder)
                        .error(R.mipmap.bg_placeholder)
                        .diskCacheStrategy(DiskCacheStrategy.ALL)
                        .centerCrop()
                        .dontAnimate()
                        .into(itemView);
            }
        });
        bgaBanner.setDelegate(new BGABanner.Delegate() {
            @Override
            public void onBannerItemClick(BGABanner banner, View itemView, Object model, int position) {
                if (bannerEntities != null && bannerEntities.size() > 0) {
                    BannerEntity entity = bannerEntities.get(position);
                    Intent intent = new Intent();
                    intent.setClass(getActivity(), WebviewActivity.class);
                    intent.putExtra("url", entity.getWxurl());
                    intent.putExtra("title", "工会新闻");
                    startActivity(intent);
                }
            }
        });

        recyclerView.setLayoutManager(new LinearLayoutManager(getActivity()));
        adapter = new NewAdapter(getActivity(), beans);
        adapter.setOnItemClickListener(new NewAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(View view, NewBean entity) {
                Intent intent = new Intent();
                intent.setClass(getActivity(), WebviewActivity.class);
                intent.putExtra("url", entity.getWxurl());
                intent.putExtra("title", "工会新闻");
                startActivity(intent);
            }
        });
        recyclerView.setAdapter(adapter);
        getBanners();
        querynewlist();
    }
    @OnClick({R.id.function01, R.id.function02, R.id.function03, R.id.function04, R.id.function05, R.id.function06, R.id.function07, R.id.function08})
    public void onClick(View view) {
        Intent intent = new Intent();
        switch (view.getId()) {
            case R.id.function01:
                intent.setClass(getActivity(), NewListActivity.class);
                startActivity(intent);
                break;
            case R.id.function02:
                break;
            case R.id.function03:
                break;
            case R.id.function04:
                break;
            case R.id.function05:
                break;
            case R.id.function06:
                break;
            case R.id.function07:
                break;
            case R.id.function08:
                break;
        }
    }

    /**
     * 加载广告
     */
    private void getBanners() {
        //4-主页广告 5-餐饮广告，6-医疗广告，7-出行广告，8-物业广告
        services.querytitlelist()
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .as(AutoDispose.<BaseResponse<List<BannerEntity>>>autoDisposable(AndroidLifecycleScopeProvider.from(this, Lifecycle.Event.ON_DESTROY)))
                .subscribe(new DefaultSubscriber<BaseResponse<List<BannerEntity>>>(getActivity()) {
                    @Override
                    public void success(BaseResponse<List<BannerEntity>> value) {
                        bannerEntities = value.getResultData();
                        List<String> urls = new ArrayList<>();
                        List<String> titles = new ArrayList<>();
                        if (value.getResultData() != null) {
                            for (BannerEntity entity : value.getResultData()) {
                                if (!TextUtils.isEmpty(entity.getPicurl())) {
                                    urls.add(entity.getPicurl());
                                    titles.add(entity.getWxtitle());
                                }
                            }
                            bgaBanner.setData(urls, titles);
                        }
                    }

                });
    }

    //加载新闻
    private void querynewlist() {
        NewListRequest request = new NewListRequest();
        request.setPageNum(1);
        request.setPageSize(5);
        services.querynewlist(request)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .as(AutoDispose.<BaseResponse<List<NewBean>>>autoDisposable(AndroidLifecycleScopeProvider.from(this, Lifecycle.Event.ON_DESTROY)))
                .subscribe(new DefaultSubscriber<BaseResponse<List<NewBean>>>(getActivity()) {
                    @Override
                    public void success(BaseResponse<List<NewBean>> value) {
                        beans.clear();
                        beans.addAll(value.getResultData());
                        adapter.notifyDataSetChanged();
                    }

                });
    }
}
