package com.yhx.union.activity;

import android.content.Intent;
import android.os.Bundle;
import android.view.View;

import androidx.lifecycle.Lifecycle;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.scwang.smart.refresh.layout.SmartRefreshLayout;
import com.scwang.smart.refresh.layout.api.RefreshLayout;
import com.scwang.smart.refresh.layout.listener.OnLoadMoreListener;
import com.scwang.smart.refresh.layout.listener.OnRefreshListener;
import com.uber.autodispose.AutoDispose;
import com.uber.autodispose.android.lifecycle.AndroidLifecycleScopeProvider;
import com.yhx.union.R;
import com.yhx.union.adapter.NewAdapter;
import com.yhx.union.entity.BaseResponse;
import com.yhx.union.entity.NewBean;
import com.yhx.union.entity.request.NewListRequest;
import com.yhx.union.public_store.ConstDefine;
import com.yhx.union.public_store.retrofit.RetrofitUtils;
import com.yhx.union.public_store.retrofit.UnionServices;
import com.yhx.union.public_store.rx.DefaultSubscriber;
import com.yhx.union.system.BaseActivity;
import com.yhx.union.system.WebviewActivity;

import java.util.ArrayList;
import java.util.List;

import butterknife.BindView;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.schedulers.Schedulers;

/**
 * 描述:
 *
 * @author yhx
 * @create 2021/9/2  8:57 AM
 */
public class NewListActivity extends BaseActivity {
    @BindView(R.id.recyclerView)
    RecyclerView recyclerView;
    @BindView(R.id.refreshLayout)
    SmartRefreshLayout refreshLayout;
    private NewAdapter mAdapter;
    private List<NewBean> newBeans = new ArrayList<>();
    private UnionServices services;
    private int pageNo = 1, stepSize = 10;
    private boolean isHasMore = false;

    @Override
    public int getContentViewLayoutID() {
        return R.layout.activity_new_list;
    }

    @Override
    public void bindViewAndEvent(Bundle savedInstanceState) {
        initTitle("工会新闻");
        services = RetrofitUtils.createApi(UnionServices.class, ConstDefine.HttpAdress);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));
        mAdapter = new NewAdapter(this, newBeans);
        mAdapter.setOnItemClickListener(new NewAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(View view, NewBean entity) {
                Intent intent = new Intent();
                intent.setClass(NewListActivity.this, WebviewActivity.class);
                intent.putExtra("url", entity.getWxurl());
                intent.putExtra("title", "工会新闻");
                startActivity(intent);
            }
        });
        recyclerView.setAdapter(mAdapter);
        refreshLayout.setOnRefreshListener(new OnRefreshListener() {
            @Override
            public void onRefresh(RefreshLayout refreshLayout) {
                pageNo = 1;
                loadDate();
            }
        });

        refreshLayout.setOnLoadMoreListener(new OnLoadMoreListener() {
            @Override
            public void onLoadMore(RefreshLayout refreshLayout) {
                loadDate();
            }
        });
        refreshLayout.autoRefresh();
    }
    //加载新闻
    private void loadDate() {
        NewListRequest request = new NewListRequest();
        request.setPageNum(1);
        request.setPageSize(5);
        services.querynewlist(request)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .as(AutoDispose.<BaseResponse<List<NewBean>>>autoDisposable(AndroidLifecycleScopeProvider.from(this, Lifecycle.Event.ON_DESTROY)))
                .subscribe(new DefaultSubscriber<BaseResponse<List<NewBean>>>(this) {
                    @Override
                    public void success(BaseResponse<List<NewBean>> value) {
                        if (value.getResultData() != null) {
                            List<NewBean> beanList = value.getResultData();
                            if (beanList != null) {
                                if (pageNo == 1) {
                                    newBeans.clear();
                                }
                                if (beanList.size() == stepSize) {
                                    isHasMore = true;
                                    pageNo++;
                                } else {
                                    isHasMore = false;
                                }
                                newBeans.addAll(beanList);
                            } else {
                                isHasMore = false;
                            }
                        } else {
                            showSnackBar("加载失败");
                        }
                        mAdapter.notifyDataSetChanged();
                        refreshComplete(refreshLayout, isHasMore);
                    }

                });
    }
}
